@@ -3,20 +3,19 @@
 #' an exponential model
 #' @param slopes_df dataset containing slopes
 #' @param kappamax indicating if kappamax was applied
+#' @param f_datetime column with datetime of each data point
 #' @importFrom dplyr select distinct mutate
 #' @importFrom tidyr pivot_longer
 #' @keywords internal
 
 flux_fortify_exp <- function(slopes_df,
-                             f_conc,
                              f_datetime,
-                             y_text_position,
                              kappamax) {
 
   if (isTRUE(kappamax)) {
-    param_df <- flux_param_kappamax(slopes_df)
+    param_df <- flux_param_kappamax(slopes_df, f_datetime = {{f_datetime}})
   } else {
-    param_df <- flux_param_exp(slopes_df)
+    param_df <- flux_param_exp(slopes_df, f_datetime = {{f_datetime}})
   }
 
   slopes_df <- flux_plot_flag(slopes_df, param_df)
